
======================
我心中真正的人工智能
======================


何为AI浪潮与低谷？
===================

目前，人工智能技术在工业界真的是火得不行，但是，在学术界，对于我们这些真正做人工智
能技术的人来说，其实并没有什么激动人心的东西，除了在CV上开了几家公司之外。如果人工
智能技术真的激动人心，那么，目前的研究生们不可能这么颓废与不上进。原因是什么？是因
为，我们知道，这些技术，就算正确率上升了几个百分点，对于我们人类的认知来说，并没有
什么实质性的提升。我们并没有获得更多的关于世界、关于人类自身的更多的、更激动的认知，
我们只不过是知道了计算机更好地能\textbf{自动化}了。

人工智能，这么伟大的一个词，原本这么激动的一个词，在如今，却让人类越来越恐慌。如果
现在一个英语教师去查看自然语言处理顶级会议ACL2016上的研究成果的时候，我觉得他会感到
压抑，因为第一篇文章 <A CALL system for learning preposition usage> [1]_ ，在如
何``设置完形填空这类的考题''这个任务上，解决了两个问题：

1. How do machine-generated items compare with human-crafted items in terms of their quality?
2. Do these items help improve the users’ language proficiency?

目前，机器不仅能自动出题，而且出得还和人类一样好！

目前，我们的人工智能技术一直在追求如何替代人类，如何“超越”人类。让去清华听吴军的人
工智能讲座的快递大哥吓怕了，未雨绸缪，赶忙征求如此有远见的人工智能大师应对之策。我人
微言轻，不敢轻易妄言什么。但我只是觉得，人工智能原本这么有意思的课题，原本这么神圣、
神奇的词，如今，为何总令人们感到害怕！？我们真的应该问问自己，我们做人工智能的目的到
底是什么？就是为了让计算机更好地自动化吗？就是为了让计算机更好地替代人类吗？

为什么人工智能有一波一波的浪潮？这都第三波了！大家觉得\textbf{人工智能能干活，所以
浪潮来了；干着干着，活干不动了，于是浪潮又下去了。}我们在人工智能技术上，真的应该如
何急功近利吗？我们做人工智能难道就只是为了能让它实用？我想，也许，几十年后的某一天，
当我们回过头来看今天人工智能顶级会议之一NIPS2016时，我们发现有一篇被收录的文章题目
叫 <Learning the Number of Neurons in Deep Networks> [2]_ 时，是否会打一个大大
的问号：哎呀，那个时候的人们到底想要什么，为何不去追求对这个未知的世界的认识、对奇
妙的自己的认识，老是想着让计算机自动干啥事？**计算机能自己找神经元数量了，你
在深度学习上获得了什么样的认知？**

我心中的人工智能，是为了追求人类对这么奇妙的自我的认知，是为了追求人类对这么未知的
世界的认知。我并没有说大家做的这些事情有什么不对，我更没有资格说。我只是想，如果人
工智能的本初是如此，那么，一波又一波的所谓浪潮，从何而来？我们在AI技术上，每天都在
进步，就算搞不动了，难道不也是一种AI技术的认知吗？所以何来低谷？又何来浪潮？

我希望人工智能技术的每一点进步，都让人类激动：“哇，原来是这样的！”我也**希望我们这
些AI研究者成为神圣的表演者，或者布道者，我们站在台上，台下是一大群观众或者信徒，我
们告诉他们，通过一次又一次的实验与思考，我们发现，“哇，原来是这样”，或者，“哇，
原来还可以这样”。**

AI不能承担认知世界的任务
========================

好吧，我承认，当我想到``哇，原来还可以这样``的时候，我突然发现，其实计算机科学一直
在做的事情，就是，``原来还可以这样``。虽然，做这些的研究者们可能并不是真正的为了追
求``还可以这样``的认知，但，至少我们回过头去看大家的成果的时候，我们会发现，原来大家
一直都是在这样做的。

当我在谈论这计算机科学到底有多追求实用主义的时候，回过头来看，就突然发现，计算机科学
天生就带着``功利``的气息。这门学科的本质就是解决实际生活中的一个又一个的问题。它就追求
这个，解决问题。没有问题要去解决，或者，不能解决实际问题，这门学科就不复存在。而真正能
承担“哇，原来是这样”的任务是，在生物学、天文学、物理学这样的学科。它们提供给我们关于
人类本身，或者关于这个世界，的认识。

``2016-11-23`` -- ``2016-11-27``

.. [1] Lee, John, et al. "A CALL System for Learning Preposition Usage."
.. [2] Alvarez, Jose M., and Mathieu Salzmann. "Learning the Number of Neurons in Deep Networks." Advances in Neural Information Processing Systems. 2016.


